==> json-schema-for-humans-0.33.1.tar.gz: json-schema-for-humans-0.33.1/docs/examples/examples_md_nested_default/description_from_ref.md <==
# Schema Docs

- [1. [Optional] Property root > name](#name)
- [2. [Optional] Property root > alignment](#alignment)

| Type                      | `object`                                                |
| ------------------------- | ------------------------------------------------------- |
| **Additional properties** | [[Not allowed]](# "Additional Properties not allowed.") |
|                           |                                                         |

<details>
<summary><strong> <a name="name"></a>1. [Optional] Property root > name</strong>  

</summary>
<blockquote>

| Type                      | `string`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/filled_string                                               |
|                           |                                                                           |

**Description:** a filled string

| Restrictions   |   |
| -------------- | - |
| **Min length** | 1 |
|                |   |

</blockquote>
</details>

<details>
<summary><strong> <a name="alignment"></a>2. [Optional] Property root > alignment</strong>  

</summary>
<blockquote>

| Type                      | `string`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Same definition as**    | `[name](#name)`                                                           |
|                           |                                                                           |

**Description:** a filled string

</blockquote>
</details>

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date

==> json-schema-for-humans-0.34.3.tar.gz: json-schema-for-humans-0.34.3/docs/examples/examples_md_nested_default/description_from_ref.md <==
# Schema Docs

- [1. [Optional] Property root > name](#name)
- [2. [Optional] Property root > alignment](#alignment)

| Type                      | `object`                                                |
| ------------------------- | ------------------------------------------------------- |
| **Additional properties** | [[Not allowed]](# "Additional Properties not allowed.") |
|                           |                                                         |

<details>
<summary><strong> <a name="name"></a>1. [Optional] Property root > name</strong>  

</summary>
<blockquote>

| Type                      | `string`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/filled_string                                               |
|                           |                                                                           |

**Description:** a filled string

| Restrictions   |   |
| -------------- | - |
| **Min length** | 1 |
|                |   |

</blockquote>
</details>

<details>
<summary><strong> <a name="alignment"></a>2. [Optional] Property root > alignment</strong>  

</summary>
<blockquote>

| Type                      | `string`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Same definition as**    | [name](#name)                                                             |
|                           |                                                                           |

**Description:** a filled string

</blockquote>
</details>

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date
